@@ -22,6 +22,13 @@ class TestPrinter(TestCase):
             print('hello')
         assert self.filename.read_text() == 'hello\n'
 
+    def test_printer_dry_run(self):
+        assert not self.filename.exists()
+        with safer.printer(self.filename, dry_run=True) as print:
+            assert not self.filename.exists()
+            print('hello')
+        assert not self.filename.exists()
+
     def test_printer_errors(self):
         with safer.printer(self.filename):
             pass
